@@ -24,6 +24,7 @@ dbdir = "/home/user/.comic-widget/"
 comiccache = "/home/user/MyDocs/.comics/"
 comics = {"xkcd":{"name":"xkcd","link":"http://xkcd.org/","start":666,"dbfile":dbdir + "comicdb.xkcd.csv"},
 		"sinfest":{"name":"Sinfest","link":"http://sinfest.com/","start":3400,"dbfile":dbdir + "comicdb.sinfest.csv"},
+		"phd":{"name":"PHD Comics","link":"http://www.phdcomics.com/","start":1240,"dbfile":dbdir + "comicdb.phd.csv"},
 		"dilbert":{"name":"Dilbert","link":"http://dilbert.com.com/","start":"2009-01-01","dbfile":dbdir + "comicdb.dilbert.csv"}}
 
 # handling of the comics
@@ -43,7 +44,7 @@ class ComicDb():
 		for row in dbr:
 			self.db.insert(0,row)
 		dbf.close()
-		self.currentcomic = 0		
+		self.currentcomic = 0
 
 
 
@@ -57,10 +58,10 @@ class ComicDb():
 		# if not, copy it.
 		else:
 			print "file " + self.dbfile + " not found"
-			if not os.path.exists(dbdir + self.comic + "/"):
-				print "path not found: " + dbdir + self.comic + "/"
+			if not os.path.exists(dbdir):
+				print "path not found: " + dbdir
 				try:
-					os.makedirs(dbdir + self.comic + "/")
+					os.makedirs(dbdir)
 				except:
 					print "comic db creation failed on mkdir"
 					exit()
@@ -68,13 +69,15 @@ class ComicDb():
 				shutil.copyfile(basedbdir + "comicdb." + self.comic + ".csv", dbdir + "comicdb." + self.comic + ".csv")
 			except:
 				print "comic db creation failed on copy"
-				exit()
+				print "creating new..."
+				dbf = open(self.dbfile, 'w')
+				dbf.write('comic,id,link,url,filename,title\n')
+				dbf.close()
 			if os.path.isfile(self.dbfile) == True:
 				dbf = open(self.dbfile, 'r')
 				return dbf
 			else:
 				print "comic db creation failed after copy"
-				exit()
 
 
 	def get_comic(self):
@@ -178,7 +181,7 @@ class ComicDb():
 	def fetch_latest_std(self, comic, latest):
 		print "fetching new after " + str(comic) + " " + str(latest)
 		dateid = False
-		if len(latest) == 10:
+		if len(str(latest)) == 10:
 			# date id.
 			dateid = True
 			dt = string.split(latest, "-")
@@ -188,11 +191,15 @@ class ComicDb():
 		else:
 			comicid = int(latest) + 1
 
-
+		lasturl = self.db[0]['url']
 		while True:
 			irow = self.get_irow(comic, comicid)
 			if irow:
 				print "got irow: " + str(irow)
+				if irow[3] == lasturl:
+					print "Looping the same, break break break!"
+					break
+				lasturl = irow[3]
 				print "inserting..."
 				self.insert_row(irow)
 				if dateid:
@@ -220,6 +227,8 @@ class ComicDb():
 			link = "http://www.sinfest.net/archive_page.php?comicID=" + str(number)
 		elif comic == 'dilbert':
 			link = "http://dilbert.com/" + str(number) + "/"
+		elif comic == 'phd':
+			link = "http://www.phdcomics.com/comics/archive.php?comicid=" + str(number)
 		else:
 			return False
 
@@ -273,6 +282,21 @@ class ComicDb():
 					return False
 				title = ""
 
+			elif comic == 'phd':
+				s = f.read()
+				f.close()
+				# title:
+				splt = string.split(s, '<title>PHD Comics: ', 1)
+				splt = string.split(splt[1], '</title>', 1)
+				title = splt[0];
+				splt = string.split(splt[1], '<td bgcolor=#FFFFFF align=center><img src=', 1)
+				splt = string.split(splt[1], ' align=top>', 1)
+				url = splt[0]
+				if len(url) < 49:
+					print "Fake 404! Break break break!"
+					return False
+				
+
 			splt2 = string.rsplit(url, "/", 1)
 			filename = splt2[1]
 			irow = [comic,number,link,url,filename,title]
@@ -288,7 +312,7 @@ class ComicHomePlugin(hildondesktop.HomePluginItem):
 		global supports_alpha
 		self.set_settings(True)
 		self.connect("show-settings", self.show_options)
-		self.osso_c = osso.Context("comic-widget", "0.0.1", False)
+		self.osso_c = osso.Context("comic-widget", "0.2.6", False)
 		self.osso_rpc = osso.Rpc(self.osso_c)
 		self.keys = comics.keys()
 		self.keypointer = 1
@@ -516,12 +540,14 @@ class ComicHomePlugin(hildondesktop.HomePluginItem):
 				self.e_goweb.show_all()
 
 			elif func == 'switch':
-				self.keypointer = (self.keypointer + 1) % 3
+				self.keypointer = (self.keypointer + 1) % len(comics)
 				self.imgvpos = 0
 				self.db = []
 				print "switching to " + self.keys[self.keypointer]
 				self.comicname = comics[self.keys[self.keypointer]]['name']
 				self.db = ComicDb(self.keys[self.keypointer])
+				self.e_open.remove(self.comic_image)
+				self.comic_image = self.get_resized_pixmap(self.db.get_comic(), self.imgvpos)
 				self.e_goweb.remove(self.label)
 				titl = str(self.db.db[self.db.currentcomic]['title'])
 				if len(titl) > 22:
@@ -529,8 +555,6 @@ class ComicHomePlugin(hildondesktop.HomePluginItem):
 				self.label.set_markup('<span size="12000" face="monospace"> <b>' + self.comicname + '</b> ' + str(self.db.db[self.db.currentcomic]['id']) + '\n ' + titl + '</span>')
 				self.e_goweb.add(self.label)
 				self.e_goweb.show_all()
-				self.e_open.remove(self.comic_image)
-				self.comic_image = self.get_resized_pixmap(self.db.get_comic(), self.imgvpos)
 				self.e_open.add(self.comic_image)
 				self.e_open.show_all()	
 
@@ -633,7 +657,7 @@ class ComicHomePlugin(hildondesktop.HomePluginItem):
 		dialog.set_name("Comic widget")
 		dialog.set_version(APP_VERSION)
 		dialog.set_copyright("Copyright 2010 Marcus Wikstrom")
-		dialog.set_authors(["Marcus Wikstrom <mece@ovi.com>\n\nSpecial thanks to Benoit Hervier, Daniel Would and Brent Chiodo\nfor some nice code to sample."])
+		dialog.set_authors(["Marcus Wikstrom <mece@ovi.com>\nLogo by Martin Wikstrom\n\nSpecial thanks to all the great python developers on t.m.o who share their code, and the helpful wizards on #maemo."])
 		# dialog.set_logo(gtk.gdk.pixbuf_new_from_file("/usr/share/touchsearch/icon.png"))
 		# dialog.set_comments("Thanks to Benoit Hervier, Daniel Would and Brent Chiodo for some nice code to sample.")
 		dialog.set_license("""This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License. <http://www.gnu.org/licenses/>.""")
